==> operation-prime-2.0.0-20140317.101053-26-sources.jar: org/gcube/data/analysis/tabulardata/operation/table/ChangeTableTypeFactory.java <==
package org.gcube.data.analysis.tabulardata.operation.table;

import java.util.ArrayList;
import java.util.List;

import javax.inject.Inject;
import javax.inject.Singleton;

import org.gcube.data.analysis.tabulardata.cube.CubeManager;
import org.gcube.data.analysis.tabulardata.model.table.Table;
import org.gcube.data.analysis.tabulardata.model.table.TableType;
import org.gcube.data.analysis.tabulardata.model.table.type.CodelistTableType;
import org.gcube.data.analysis.tabulardata.model.table.type.DatasetTableType;
import org.gcube.data.analysis.tabulardata.model.table.type.GenericTableType;
import org.gcube.data.analysis.tabulardata.operation.OperationId;
import org.gcube.data.analysis.tabulardata.operation.factories.types.TableTransformationWorkerFactory;
import org.gcube.data.analysis.tabulardata.operation.invocation.OperationInvocation;
import org.gcube.data.analysis.tabulardata.operation.parameters.Cardinality;
import org.gcube.data.analysis.tabulardata.operation.parameters.Parameter;
import org.gcube.data.analysis.tabulardata.operation.parameters.leaves.MultivaluedStringParameter;
import org.gcube.data.analysis.tabulardata.operation.worker.Worker;
import org.gcube.data.analysis.tabulardata.operation.worker.exceptions.InvalidInvocationException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.google.common.collect.Lists;

@Singleton
public class ChangeTableTypeFactory extends TableTransformationWorkerFactory {

	static final String TABLE_TYPE_PARAMETER_ID = "tableType";

	private static final OperationId OPERATION_ID = new OperationId(1002);

	private final static List<TableType> availableTableTypes = new ArrayList<TableType>();

	private static final Logger log = LoggerFactory.getLogger(ChangeTableTypeFactory.class);

	static {
		availableTableTypes.add(new GenericTableType());
		availableTableTypes.add(new DatasetTableType());
		availableTableTypes.add(new CodelistTableType());
	}

	@Inject
	private CubeManager cubeManager;

	public List<String> getAdmittedValues() {
		List<String> admittedValues = Lists.newArrayList();
		for (TableType availableTableType : availableTableTypes) {
			admittedValues.add(availableTableType.getName());
		}
		return admittedValues;
	}

	public Worker createWorker(OperationInvocation invocation) throws InvalidInvocationException {
		performBaseChecks(invocation);
		checkInvocation(invocation);
		Table targetTable = cubeManager.getTable(invocation.getTargetTableId());
		String targetTableTypeName = (String) invocation.getParameterInstances().get(TABLE_TYPE_PARAMETER_ID);
		TableType targetTableType = getTableType(targetTableTypeName);
		return new ChangeTableType(invocation, cubeManager, targetTable, targetTableType);
	}

	public TableType getTableType(String targetTableTypeName) {
		TableType targetTableType = null;
		for (TableType availableTableType : availableTableTypes) {
			if (availableTableType.getName().equals(targetTableTypeName))
				targetTableType = availableTableType;
		}
		return targetTableType;
	}

	private void checkInvocation(OperationInvocation invocation) throws InvalidInvocationException {
		try {
			List<String> admittedValues = getAdmittedValues();
			String tableTypeName = (String) invocation.getParameterInstances().get(TABLE_TYPE_PARAMETER_ID);
			if (!admittedValues.contains(tableTypeName))
				throw new InvalidInvocationException(invocation,
						"Provided value is not admitted: " + tableTypeName);
		} catch (InvalidInvocationException e) {
			throw e;
		} catch (Exception e) {
			log.error("Invalid invocation caused by exception", e);
			throw new InvalidInvocationException(invocation, "Uncaught exception caused invocation check to fail",e);
		}
	}

	@Override
	protected String getOperationName() {
		return "Change table type";
	}

	@Override
	protected String getOperationDescription() {
		return "Modify the table type";
	}

	@Override
	protected OperationId getOperationId() {
		return OPERATION_ID;
	}

	@Override
	protected List<Parameter> getParameters() {
		List<Parameter> parameters = new ArrayList<Parameter>();
		List<String> admittedValues = getAdmittedValues();
		Parameter tableTypeParameter = new MultivaluedStringParameter(TABLE_TYPE_PARAMETER_ID, "Table Type",
				"Table type", Cardinality.ONE, admittedValues);
		parameters.add(tableTypeParameter);
		return parameters;
	}

}

==> operation-prime-2.0.1-20140325.104427-6-sources.jar: org/gcube/data/analysis/tabulardata/operation/table/ChangeTableTypeFactory.java <==
package org.gcube.data.analysis.tabulardata.operation.table;

import java.util.ArrayList;
import java.util.List;

import javax.inject.Inject;
import javax.inject.Singleton;

import org.gcube.data.analysis.tabulardata.cube.CubeManager;
import org.gcube.data.analysis.tabulardata.model.table.Table;
import org.gcube.data.analysis.tabulardata.model.table.TableType;
import org.gcube.data.analysis.tabulardata.model.table.type.CodelistTableType;
import org.gcube.data.analysis.tabulardata.model.table.type.DatasetTableType;
import org.gcube.data.analysis.tabulardata.model.table.type.GenericTableType;
import org.gcube.data.analysis.tabulardata.operation.OperationId;
import org.gcube.data.analysis.tabulardata.operation.factories.types.TableTransformationWorkerFactory;
import org.gcube.data.analysis.tabulardata.operation.invocation.OperationInvocation;
import org.gcube.data.analysis.tabulardata.operation.parameters.Cardinality;
import org.gcube.data.analysis.tabulardata.operation.parameters.Parameter;
import org.gcube.data.analysis.tabulardata.operation.parameters.leaves.MultivaluedStringParameter;
import org.gcube.data.analysis.tabulardata.operation.worker.Worker;
import org.gcube.data.analysis.tabulardata.operation.worker.exceptions.InvalidInvocationException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.google.common.collect.Lists;

@Singleton
public class ChangeTableTypeFactory extends TableTransformationWorkerFactory {

	static final String TABLE_TYPE_PARAMETER_ID = "tableType";

	private static final OperationId OPERATION_ID = new OperationId(1002);

	private final static List<TableType> availableTableTypes = new ArrayList<TableType>();

	private static final Logger log = LoggerFactory.getLogger(ChangeTableTypeFactory.class);

	static {
		availableTableTypes.add(new GenericTableType());
		availableTableTypes.add(new DatasetTableType());
		availableTableTypes.add(new CodelistTableType());
	}

	@Inject
	private CubeManager cubeManager;

	public List<String> getAdmittedValues() {
		List<String> admittedValues = Lists.newArrayList();
		for (TableType availableTableType : availableTableTypes) {
			admittedValues.add(availableTableType.getName());
		}
		return admittedValues;
	}

	public Worker createWorker(OperationInvocation invocation) throws InvalidInvocationException {
		performBaseChecks(invocation,cubeManager);
		checkInvocation(invocation);
		Table targetTable = cubeManager.getTable(invocation.getTargetTableId());
		String targetTableTypeName = (String) invocation.getParameterInstances().get(TABLE_TYPE_PARAMETER_ID);
		TableType targetTableType = getTableType(targetTableTypeName);
		return new ChangeTableType(invocation, cubeManager, targetTable, targetTableType);
	}

	public TableType getTableType(String targetTableTypeName) {
		TableType targetTableType = null;
		for (TableType availableTableType : availableTableTypes) {
			if (availableTableType.getName().equals(targetTableTypeName))
				targetTableType = availableTableType;
		}
		return targetTableType;
	}

	private void checkInvocation(OperationInvocation invocation) throws InvalidInvocationException {
		try {
			List<String> admittedValues = getAdmittedValues();
			String tableTypeName = (String) invocation.getParameterInstances().get(TABLE_TYPE_PARAMETER_ID);
			if (!admittedValues.contains(tableTypeName))
				throw new InvalidInvocationException(invocation,
						"Provided value is not admitted: " + tableTypeName);
		} catch (InvalidInvocationException e) {
			throw e;
		} catch (Exception e) {
			log.error("Invalid invocation caused by exception", e);
			throw new InvalidInvocationException(invocation, "Uncaught exception caused invocation check to fail",e);
		}
	}

	@Override
	protected String getOperationName() {
		return "Change table type";
	}

	@Override
	protected String getOperationDescription() {
		return "Modify the table type";
	}

	@Override
	protected OperationId getOperationId() {
		return OPERATION_ID;
	}

	@Override
	protected List<Parameter> getParameters() {
		List<Parameter> parameters = new ArrayList<Parameter>();
		List<String> admittedValues = getAdmittedValues();
		Parameter tableTypeParameter = new MultivaluedStringParameter(TABLE_TYPE_PARAMETER_ID, "Table Type",
				"Table type", Cardinality.ONE, admittedValues);
		parameters.add(tableTypeParameter);
		return parameters;
	}

}
